package com.kxs.lhb.basic.biz.controller.cusmoter;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.core.valid.group.Insert;
import com.kxs.common.core.valid.group.Update;
import com.kxs.lhb.basic.api.model.LhbOrder;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 订单管理(Order)控制层
 *
 * @author 系统
 * @since 2024-10-22 14:41:49
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("order")
@Tag(description = "order", name = "Order")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class OrderController {

    /**
     * 服务对象
     */
    private final LhbOrderService lhbOrderService;



    /**
     * 预占号码
     *
     * @RequestBody param 实体参数
     * @return 下单
     */
    @PostMapping("/prePhone")
    public R prePhone(@Validated({Insert.class}) @RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.prePhone(param));
    }


    /**
     * 下单
     *
     * @RequestBody param 实体参数
     * @return 下单
     */
    @PostMapping("/submit")
    public R submit(@Validated({Update.class}) @RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.submit(param));
    }


    /**
     * 我的订单
     *
     * @param page 分页对象
     * @return 我的订单
     */
    @GetMapping("/myOrder")
    public R myOrder(@ParameterObject Page<LhbOrder> page) {

        return R.ok(lhbOrderService.page(page, Wrappers.lambdaQuery(LhbOrder.class).orderByDesc(LhbOrder::getId)));
    }


    /**
     * 查看物流信息
     *
     * @RequestParam param 实体参数
     * @return 查看物流信息
     */
    @GetMapping("/queryLogistics")
    public R queryLogistics(@RequestParam("id") Integer id) {

        return R.ok(lhbOrderService.queryLogistics(id));
    }


    /**
     * 发起支付
     *
     * @RequestBody param 实体参数
     * @return 发起支付
     */
    @PostMapping("/payOrder")
    public R payOrder(@RequestBody LhbOrder param) {
        return R.ok(lhbOrderService.payOrder(param));
    }





}

